==> openshift-client-4.13.0-sources.jar: io/fabric8/openshift/client/dsl/internal/ClusterRoleOperationsImpl.java <==

                
  

package io.fabric8.openshift.client.dsl.internal;

import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.DoneableClusterRole;
import io.fabric8.openshift.api.model.ClusterRole;
import io.fabric8.openshift.api.model.ClusterRoleList;
import io.fabric8.openshift.api.model.DoneableClusterRole;

import java.util.Map;
import java.util.TreeMap;


public class ClusterRoleOperationsImpl extends OpenShiftOperation<ClusterRole, ClusterRoleList, DoneableClusterRole, Resource<ClusterRole, DoneableClusterRole>> {

  public ClusterRoleOperationsImpl(OkHttpClient client, OpenShiftConfig config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public ClusterRoleOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("authorization.openshift.io")
    .withApiGroupVersion("v1")
    .withPlural("clusterroles"));
    this.type = ClusterRole.class;
    this.listType = ClusterRoleList.class;
    this.doneableType = DoneableClusterRole.class;
  }

  public ClusterRoleOperationsImpl newInstance(OperationContext context) {
    return new ClusterRoleOperationsImpl(context);
  }
  
  @Override
  public boolean isResourceNamespaced() {
    return false;
  }
}

==> openshift-client-5.1.1-sources.jar: io/fabric8/openshift/client/dsl/internal/ClusterRoleOperationsImpl.java <==

                            
  

package io.fabric8.openshift.client.dsl.internal;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.ClusterRole;
import io.fabric8.openshift.api.model.ClusterRoleBuilder;
import io.fabric8.openshift.api.model.ClusterRoleList;

import java.util.Map;
import java.util.TreeMap;


public class ClusterRoleOperationsImpl extends OpenShiftOperation<ClusterRole, ClusterRoleList, Resource<ClusterRole>> {

  public ClusterRoleOperationsImpl(OkHttpClient client, OpenShiftConfig config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public ClusterRoleOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("authorization.openshift.io")
    .withApiGroupVersion("v1")
    .withPlural("clusterroles"));
    this.type = ClusterRole.class;
    this.listType = ClusterRoleList.class;
  }

  public ClusterRoleOperationsImpl newInstance(OperationContext context) {
    return new ClusterRoleOperationsImpl(context);
  }

  @Override
  public ClusterRole edit(Visitor... visitors) {
    return patch(new ClusterRoleBuilder(getMandatory()).accept(visitors).build());
  }
 
  @Override
  public boolean isResourceNamespaced() {
    return false;
  }
}
